#!/bin/bash
# Download and install plugin. This downloads plugin jar from release or development repo based on version. 
# If version has "SNAPSHOT" as part of it, dev repo will be used.
# Arguments :
#    Plugins - expects plugin details in format : "<plugin_name_1>=<plugin_version_1>,<plugin_name_2>=<plugin_version_2>"
#
# Usage :
#	/resources/install_insight_plugin.sh "ArtifactoryClientPlugin=1.0,index-rollover=1.0"

PLUGIN_HOME="/jfrog_insight_plugins"
PLUGIN_REPO="insight-dependencies"

errorExit() {
    echo; echo -e "\033[31mERROR:\033[0m $1"; echo
    exit 1
}

# Install provided comma seperated plugins
PLUGINS=$1
for PLUGIN_DETAILS in ${PLUGINS//,/ }
do
	# extract plugin name and version
	PLUGIN=`echo $PLUGIN_DETAILS | awk -F "=" '{print $1}'`  
	VERSION=`echo $PLUGIN_DETAILS | awk -F "=" '{print $2}'`

	# exit if plugin and version is entered as expected
	[ -z "$PLUGIN" ] && errorExit "Installation of plugins failed, please check entered plugin details"
	[ -z "$VERSION" ] && errorExit "Installation of plugins failed, please check entered plugin details"

	echo -e "\nInstalling plugin $PLUGIN : $VERSION\n"

	# construct plugin zip name and repo path
	PLUGIN_ZIP="$PLUGIN-$VERSION-bundle.zip"
	PLUGIN_REPO_PATH="$PLUGIN_REPO/com/jfrog/insight/$PLUGIN/$VERSION/$PLUGIN_ZIP"

	# download and install in provided destination
	set -x && \
	source /resources/.artifactory_env && \
	ARTIFACTORY_CONTEXTURL_WITH_TOKEN=$(echo $artifactory_contextUrl | sed -e "s~\([^://]\)://\(.*\)~\1://${artifactory_user}:${artifactory_token}@\2~g") && \
	mkdir -p "$PLUGIN_HOME" && \
	cd "$PLUGIN_HOME" && \
	wget "$ARTIFACTORY_CONTEXTURL_WITH_TOKEN/$PLUGIN_REPO_PATH" && \
	unzip "$PLUGIN_ZIP" && rm "$PLUGIN_ZIP" ; mv "$PLUGIN-$VERSION/$PLUGIN" "$PLUGIN_HOME/" ; find "$PLUGIN-$VERSION" -type d -empty -delete
done